==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/ParameterValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ParameterValue;
import io.ciera.tool.sql.ooaofooa.value.ParameterValueSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.List;


public class ParameterValueSetImpl extends InstanceSet<ParameterValueSet,ParameterValue> implements ParameterValueSet {

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setTParm_ID( UniqueId ref_TParm_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setTParm_ID( ref_TParm_ID );
    }
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setPP_Id( ref_PP_Id );
    }
    @Override
    public void setSParm_ID( UniqueId ref_SParm_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setSParm_ID( ref_SParm_ID );
    }
    @Override
    public void setBParm_ID( UniqueId ref_BParm_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setBParm_ID( ref_BParm_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ParameterValue parametervalue : this ) valueset.add( parametervalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public BridgeParameterSet R831_is_a_value_of_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( ParameterValue parametervalue : this ) bridgeparameterset.add( parametervalue.R831_is_a_value_of_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public FunctionParameterSet R832_is_a_value_of_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( ParameterValue parametervalue : this ) functionparameterset.add( parametervalue.R832_is_a_value_of_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public OperationParameterSet R833_is_a_value_of_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( ParameterValue parametervalue : this ) operationparameterset.add( parametervalue.R833_is_a_value_of_OperationParameter() );
        return operationparameterset;
    }
    @Override
    public PropertyParameterSet R843_is_a_value_of_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( ParameterValue parametervalue : this ) propertyparameterset.add( parametervalue.R843_is_a_value_of_PropertyParameter() );
        return propertyparameterset;
    }


    @Override
    public ParameterValue nullElement() {
        return ParameterValueImpl.EMPTY_PARAMETERVALUE;
    }

    @Override
    public ParameterValueSet emptySet() {
      return new ParameterValueSetImpl();
    }

    @Override
    public ParameterValueSet value() {
        return this;
    }

    @Override
    public List<ParameterValue> elements() {
        return Arrays.asList(toArray(new ParameterValue[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/value/impl/ParameterValueSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.value.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.impl.PropertyParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.FunctionParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.FunctionParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.value.ParameterValue;
import io.ciera.tool.sql.ooaofooa.value.ParameterValueSet;
import io.ciera.tool.sql.ooaofooa.value.ValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.ValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ParameterValueSetImpl extends InstanceSet<ParameterValueSet,ParameterValue> implements ParameterValueSet {

    public ParameterValueSetImpl() {
    }

    public ParameterValueSetImpl(Comparator<? super ParameterValue> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setValue_ID( UniqueId ref_Value_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setValue_ID( ref_Value_ID );
    }
    @Override
    public void setPP_Id( UniqueId ref_PP_Id ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setPP_Id( ref_PP_Id );
    }
    @Override
    public void setBParm_ID( UniqueId ref_BParm_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setBParm_ID( ref_BParm_ID );
    }
    @Override
    public void setSParm_ID( UniqueId ref_SParm_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setSParm_ID( ref_SParm_ID );
    }
    @Override
    public void setTParm_ID( UniqueId ref_TParm_ID ) throws XtumlException {
        for ( ParameterValue parametervalue : this ) parametervalue.setTParm_ID( ref_TParm_ID );
    }


    // selections
    @Override
    public ValueSet R801_is_a_Value() throws XtumlException {
        ValueSet valueset = new ValueSetImpl();
        for ( ParameterValue parametervalue : this ) valueset.add( parametervalue.R801_is_a_Value() );
        return valueset;
    }
    @Override
    public BridgeParameterSet R831_is_a_value_of_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( ParameterValue parametervalue : this ) bridgeparameterset.add( parametervalue.R831_is_a_value_of_BridgeParameter() );
        return bridgeparameterset;
    }
    @Override
    public FunctionParameterSet R832_is_a_value_of_FunctionParameter() throws XtumlException {
        FunctionParameterSet functionparameterset = new FunctionParameterSetImpl();
        for ( ParameterValue parametervalue : this ) functionparameterset.add( parametervalue.R832_is_a_value_of_FunctionParameter() );
        return functionparameterset;
    }
    @Override
    public OperationParameterSet R833_is_a_value_of_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( ParameterValue parametervalue : this ) operationparameterset.add( parametervalue.R833_is_a_value_of_OperationParameter() );
        return operationparameterset;
    }
    @Override
    public PropertyParameterSet R843_is_a_value_of_PropertyParameter() throws XtumlException {
        PropertyParameterSet propertyparameterset = new PropertyParameterSetImpl();
        for ( ParameterValue parametervalue : this ) propertyparameterset.add( parametervalue.R843_is_a_value_of_PropertyParameter() );
        return propertyparameterset;
    }


    @Override
    public ParameterValue nullElement() {
        return ParameterValueImpl.EMPTY_PARAMETERVALUE;
    }

    @Override
    public ParameterValueSet emptySet() {
      return new ParameterValueSetImpl();
    }

    @Override
    public ParameterValueSet emptySet(Comparator<? super ParameterValue> comp) {
      return new ParameterValueSetImpl(comp);
    }

    @Override
    public ParameterValueSet value() {
        return this;
    }

    @Override
    public List<ParameterValue> elements() {
        return Arrays.asList(toArray(new ParameterValue[0]));
    }

}
